define(
//begin v1.x content
({
	insertTableTitle: "Tablo Ekle",
	modifyTableTitle: "Tabloyu Değiştir",
	rows: "Satırlar:",
	columns: "Sütunlar:",
	align: "Hizala:",
	cellPadding: "Hücre Doldurma:",
	cellSpacing: "Hücre Aralığı:",
	tableWidth: "Tablo Genişliği",
	backgroundColor: "Arka Plan Rengi:",
	borderColor: "Kenarlık Rengi:",
	borderThickness: "Kenarlık Kalınlığı",
	percent: "yüzde",
	pixels: "piksel",
	"default": "varsayılan",
	left: "sol",
	center: "orta",
	right: "sağ",
	buttonSet: "Ayarla", // translated elsewhere?
	buttonInsert: "Ekle",
	buttonCancel: "İptal",

	selectTableLabel: "Tablo Seç",
	insertTableRowBeforeLabel: "Satırı Önüne Ekle",
	insertTableRowAfterLabel: "Satırı Arkasına Ekle",
	insertTableColumnBeforeLabel: "Sütunu Önüne Ekle",
	insertTableColumnAfterLabel: "Sütunu Arkasına Ekle",
	deleteTableRowLabel: "Satırı Sil",
	deleteTableColumnLabel: "Sütunu Sil"
})
//end v1.x content
);
